@@ -579,9 +579,19 @@ CORBA_ORB_string_to_object (CORBA_ORB          orb,
 		    strstr (string, "://")) {
 			/* FIXME: this code is a security hazard */
 			ior = orb_http_resolve (string);
-			if (!ior)
-				return CORBA_OBJECT_NIL;
+			if (!ior) {
+				/* FIXME, set error minor code
+				 * (vendor's error code) to tell user
+				 * initial location of error, ie my
+				 * local ORB, proxy's ORB, server's
+				 * ORB, etc. */
+				CORBA_exception_set_system (
+					ev,
+					ex_CORBA_BAD_PARAM,
+					CORBA_COMPLETED_NO);
 
+				return CORBA_OBJECT_NIL;
+			}
 			string = ior;
 		} else 
 #endif
@@ -1412,6 +1422,19 @@ ORBit_proto_use (const char *name)
 	return FALSE;
 }
 
+/**
+ * ORBit_get_giop_recv_limit:
+ * 
+ * This function will return the GIOP receive limit. The
+ * GIOP receive limit is the maximum number of bytes that
+ * are allowed be received in any one ingoing GIOP 
+ * communication. This function is essential if an application
+ * is about to receive a big amount of data. Knowing the GIOP 
+ * receive limit will enable the application to poll to data
+ * in chunks that are below the receive limit.
+ *
+ * Since: 2.14.1
+ */
 glong
 ORBit_get_giop_recv_limit (void)
 {
